@@ -1,3 +1,4 @@
+#' @include corpus.R
 #' @include dictionaries.R
 NULL
 
@@ -100,9 +101,9 @@ collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=
                             count = 1)
     
     # eliminate non-adjacent words
-    wordpairs <- wordpairs[!(stri_detect_regex(w1, "^[:punct:]$") | 
-                             stri_detect_regex(w2, "^[:punct:]$") |
-                             stri_detect_regex(w3, "^[:punct:]$"))]
+    wordpairs <- wordpairs[!(stri_detect_regex(w1, "^\\p{P}$") | 
+                             stri_detect_regex(w2, "^\\p{P}$") |
+                             stri_detect_regex(w3, "^\\p{P}$"))]
 
     # set the data.table sort key
     setkey(wordpairs, w1, w2, w3)
@@ -312,139 +313,6 @@ collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=
 
 
 
-#' convert phrases into single tokens
-#' 
-#' Replace multi-word phrases in text(s) with a compound version of the phrases 
-#' concatenated with  \code{concatenator} (by default, the "\code{_}" character) to
-#' form a single token.  This prevents tokenization of the phrases during 
-#' subsequent processing by eliminating the whitespace delimiter.
-#' @param object source texts, a character or character vector
-#' @param phrases a \code{\link{dictionary}} object that 
-#'   contains some phrases, defined as multiple words delimited by whitespace, 
-#'   up to 9 words long; or a quanteda collocation object created
-#'   by \code{\link{collocations}}
-#' @param concatenator the concatenation character that will connect the words 
-#'   making up the multi-word phrases.  The default \code{_} is highly 
-#'   recommended since it will not be removed during normal cleaning and 
-#'   tokenization (while nearly all other punctuation characters, at least those
-#'   in the POSIX class \code{[:punct:]}) will be removed.
-#' @return character or character vector of texts with phrases replaced by 
-#'   compound "words" joined by the concatenator
-#' @export
-#' @author Kenneth Benoit
-#' @examples
-#' mytexts <- c("The new law included a capital gains tax, and an inheritance tax.",
-#'              "New York City has raised a taxes: an income tax and a sales tax.")
-#' mydict <- dictionary(list(tax=c("tax", "income tax", "capital gains tax", "inheritance tax")))
-#' (cw <- phrasetotoken(mytexts, mydict))
-#' dfm(cw, verbose=FALSE)
-#' 
-#' # when used as a dictionary for dfm creation
-#' mydfm2 <- dfm(cw, dictionary = lapply(mydict, function(x) gsub(" ", "_", x)))
-#' mydfm2
-#' # to pick up "taxes" in the second text, set valuetype = "regex"
-#' mydfm3 <- dfm(cw, dictionary = lapply(mydict, phrasetotoken, mydict),
-#'               valuetype = "regex")
-#' mydfm3
-#' ## one more token counted for "tax" than before
-setGeneric("phrasetotoken", 
-           function(object, phrases, concatenator="_") standardGeneric("phrasetotoken"))
-# phrasetotoken <- function(x, dictionary, concatenator = "_") {
-#     UseMethod("phrasetotoken")
-# }
-
-#' @rdname phrasetotoken
-#' @export
-setMethod("phrasetotoken", signature=c("character", "dictionary", "ANY"), 
-          function(object, phrases, concatenator="_") {
-              phrases <- unlist(phrases, use.names=FALSE)
-              compoundPhrases <- phrases[stringi::stri_detect_fixed(phrases, " ")]
-              # now replace hyphens with something else
-              compoundPhrases <- stringi::stri_replace_all_fixed(compoundPhrases, "-", "__")
-              compoundPhrasesList <- tokenize(compoundPhrases)
-              
-              # replace intra-word hyphens in text with __
-              object <- stringi::stri_replace_all_regex(object, "(\\w+)[-](\\w+)", "$1__$2")
-              
-              for (l in compoundPhrasesList) {
-                  # match phrases with space delimiters or (already added) concatenator
-                  # this catches trigram collocations that have already been processed partly as bigrams
-                  re.pattern <- paste("(", paste(l, collapse=paste0(")[\\s", concatenator, "](")), ")", sep="")
-                  re.replace <- paste("$", 1:length(l), sep="", collapse=concatenator)
-                  object <- stringi::stri_replace_all_regex(object, re.pattern, re.replace, case_insensitive=TRUE)
-              }
-              # now transform hyphens back
-              object <- stringi::stri_replace_all_fixed(object, "__", "-")
-              object
-          })
-
-#  need an S3 method for the S3 corpus object
-#' @rdname phrasetotoken
-#' @export
-phrasetotoken.corpus <- function(object, phrases, concatenator="_") {
-    texts(object) <- phrasetotoken(texts(object), phrases, concatenator)
-    object
-}
-
-
-setClass("collocations", contains = "data.table")
-
-#' @rdname phrasetotoken
-#' @export
-setMethod("phrasetotoken", signature=c("character", "collocations", "ANY"), 
-          function(object, phrases, concatenator="_") {
-              word1 <- word2 <- word3 <- NULL
-              # concatenate the words                               
-              word123 <- phrases[, list(word1, word2, word3)]
-              mwes <- apply(word123, 1, paste, collapse=" ")
-              # strip trailing white space (if no word 3)
-              mwes <- gsub("\\s$", "", mwes)
-              
-              phrasetotoken(object, dictionary(list(mwes=mwes)), concatenator)
-          })
-
-
-# @rdname phrasetotoken
-# @export
-# phrasetotoken.character <- function(x, dictionary, concatenator="_") {
-#     # get the tokenized list of compound phrases from a dictionary (list)
-#     phrases <- unlist(dictionary, use.names=FALSE)
-#     compoundPhrases <- phrases[grep(" ", phrases)]
-#     compoundPhrasesList <- tokenize(compoundPhrases)
-#     
-#     # contenate the phrases in
-#     # gsub("(word1)\\s(word2)", "\\1_\\2", "word1 word2")
-#     ## [1] "word1_word2"
-#     for (l in compoundPhrasesList) {
-#         re.pattern <- paste("(", 
-#                             paste(l, collapse=")\\s("),
-#                             ")", sep="")
-#         re.replace <- paste("\\", 1:length(l), sep="", collapse=concatenator)
-#         x <- gsub(re.pattern, re.replace, x, perl=TRUE)
-#     }
-#     x    
-# }
-
-# gapTokenize <- function(txt) {
-#     tokenVec <- tokenize(txt, removePunct=FALSE, simplify=TRUE)
-#     punctEndIndex <- grep("[])};:,.?!]", tokenVec) # don't pad if last token
-#     if (length(punctEndIndex) > 0) {
-#         for (i in 1:(length(punctEndIndex))) {
-#             if (punctEndIndex[i]+i-1 == length(tokenVec)) break
-#             tokenVec <- c(tokenVec[1:(i-1+punctEndIndex[i])], "", tokenVec[(i+punctEndIndex[i]):length(tokenVec)])
-#         }
-#     }
-#     punctBegIndex <- grep("[[({]", tokenVec)
-#     if (length(punctBegIndex) > 0) {
-#         for (i in 1:(length(punctBegIndex))) {
-#             if (punctBegIndex[i] == 1) continue  # don't pad if first token
-#             tokenVec <- c(tokenVec[1:(i-2+punctBegIndex[i])], "", tokenVec[(i-1+punctBegIndex[i]):length(tokenVec)])
-#         }
-#     }
-#     # now remove the rest of the stuff not yet cleaned
-#     clean(tokenVec, removeDigits = FALSE, toLower = FALSE, removeURL = FALSE)
-# }
-
 
 #' @rdname collocations
 #' @export    
