@@ -6,22 +6,21 @@
 #' @method summary character
 #' @export
 #' @examples
-#' # 
+#' 
 #' # summarize texts
-#' summary(c("testing this text", "and this one"))
+#' summary(c("Testing this text.  Second sentence.", "And this one."))
 #' summary(ukimmigTexts)
-#' myTextSummaryDF <- summary(ukimmigTexts, verbose=FALSE)
-summary.character <- function(object, verbose=TRUE, ...) {
-    # need to implement subsetting here too
+#' myTextSummaryDF <- summary(ukimmigTexts, verbose = FALSE)
+#' head(myTextSummaryDF)
+summary.character <- function(object, n = 100, verbose = TRUE, toLower = FALSE, ...) {
+    object <- object[1 : min(c(n, length(object)))]
     if (is.null(names(object))) 
         names(object) <- paste("text", 1:length(object), sep="")
-    tokenizedTexts <- tokenize(toLower(object), removePunct=TRUE)
-    ntokens <- sapply(tokenizedTexts, length, USE.NAMES = FALSE)
-    ntypes <- sapply(lapply(tokenizedTexts, unique), length, USE.NAMES = FALSE)
-    # because we still don't have a generic sentence segmenter
-    # broken
-    nsents  <- sapply(tokenize(object, what = "sentence"), length, USE.NAMES = FALSE)
-    
+    nsents  <- nsentence(object, ...)
+    if (toLower) object <- toLower(object)
+    toks <- tokenize(object, ...)
+    ntokens <- ntoken(toks)
+    ntypes <- ntype(toks)
     results <- data.frame(Text=names(object),
                           Types=ntypes,
                           Tokens=ntokens,
@@ -33,7 +32,7 @@ summary.character <- function(object, verbose=TRUE, ...) {
 
 #' @rdname summary.corpus
 #' @export
-describeTexts <- function(object, verbose=TRUE, ...) {
+describeTexts <- function(object, n = 100, verbose=TRUE, ...) {
     cat("note: describeTexts is deprecated, use summary instead.\n")
     UseMethod("summary.character")
 }
